Struct etcd_client::CampaignResponse [−][src]
#[repr(transparent)]pub struct CampaignResponse(_);
Response for Campaign operation.
Implementations
impl CampaignResponse[src]
impl CampaignResponse[src]pub fn header(&self) -> Option<&ResponseHeader>[src]
Get response header.
pub fn take_header(&mut self) -> Option<ResponseHeader>[src]
Takes the header out of the response, leaving a None in its place.
pub fn leader(&self) -> Option<&LeaderKey>[src]
Describes the resources used for holding leadership of the election.
pub fn take_leader(&mut self) -> Option<LeaderKey>[src]
Takes the leader out of the response, leaving a None in its place.