Struct etcd_client::DeleteOptions [−][src]
#[repr(transparent)]pub struct DeleteOptions(_);
Options for Delete operation.
Implementations
impl DeleteOptions[src]
impl DeleteOptions[src]pub const fn new() -> Self[src]
Creates a DeleteOptions.
pub fn with_range(self, end_key: impl Into<Vec<u8>>) -> Self[src]
end_key is the key following the last key to delete for the range [key, end_key).
If end_key is not given, the range is defined to contain only the key argument.
If end_key is one bit larger than the given key, then the range is all the keys
with the prefix (the given key).
If end_key is ‘\0’, the range is all keys greater than or equal to the key argument.
pub const fn with_prev_key(self) -> Self[src]
If prev_kv is set, etcd gets the previous key-value pairs before deleting it.
The previous key-value pairs will be returned in the delete response.