Struct etcd_client::ElectionClient [−][src]
#[repr(transparent)]pub struct ElectionClient { /* fields omitted */ }
Client for Elect operations.
Implementations
impl ElectionClient[src]
impl ElectionClient[src]pub async fn campaign(
&mut self,
name: impl Into<Vec<u8>>,
value: impl Into<Vec<u8>>,
lease: i64
) -> Result<CampaignResponse, Error>[src]
&mut self,
name: impl Into<Vec<u8>>,
value: impl Into<Vec<u8>>,
lease: i64
) -> Result<CampaignResponse, Error>
Puts a value as eligible for the election on the prefix key. Multiple sessions can participate in the election for the same prefix, but only one can be the leader at a time.
pub async fn proclaim(
&mut self,
value: impl Into<Vec<u8>>,
options: Option<ProclaimOptions>
) -> Result<ProclaimResponse, Error>[src]
&mut self,
value: impl Into<Vec<u8>>,
options: Option<ProclaimOptions>
) -> Result<ProclaimResponse, Error>
Lets the leader announce a new value without another election.
pub async fn leader(
&mut self,
name: impl Into<Vec<u8>>
) -> Result<LeaderResponse, Error>[src]
&mut self,
name: impl Into<Vec<u8>>
) -> Result<LeaderResponse, Error>
Returns the leader value for the current election.
pub async fn observe(
&mut self,
name: impl Into<Vec<u8>>
) -> Result<ObserveStream, Error>[src]
&mut self,
name: impl Into<Vec<u8>>
) -> Result<ObserveStream, Error>
Returns a channel that reliably observes ordered leader proposals as GetResponse values on every current elected leader key.
pub async fn resign(
&mut self,
option: Option<ResignOptions>
) -> Result<ResignResponse, Error>[src]
&mut self,
option: Option<ResignOptions>
) -> Result<ResignResponse, Error>
Releases election leadership and then start a new election