Struct etcd_client::GetResponse [−][src]
#[repr(transparent)]pub struct GetResponse(_);
Response for Get operation.
Implementations
impl GetResponse[src]
impl GetResponse[src]pub fn header(&self) -> Option<&ResponseHeader>[src]
Get response header.
pub fn take_header(&mut self) -> Option<ResponseHeader>[src]
Takes the header out of the response, leaving a None in its place.
pub fn kvs(&self) -> &[KeyValue][src]
The list of key-value pairs matched by the Get request.
kvs is empty when count is requested.
pub const fn more(&self) -> bool[src]
Indicates if there are more keys to return in the requested range.
pub const fn count(&self) -> i64[src]
The number of keys within the range when requested.