Struct etcd_client::HashResponse [−][src]
#[repr(transparent)]pub struct HashResponse(_);
Response for hash operation.
Implementations
impl HashResponse[src]
impl HashResponse[src]pub fn header(&self) -> Option<&ResponseHeader>[src]
Get response header.
pub fn take_header(&mut self) -> Option<ResponseHeader>[src]
Takes the header out of the response, leaving a None in its place.
pub fn hash(&self) -> u32[src]
Gets the hash value computed from the responding member’s KV’s backend.