pub struct LeaseClientPrefix { /* private fields */ }Implementations
Sourceimpl LeaseClientPrefix
impl LeaseClientPrefix
Sourcepub fn new(lease: LeaseClient, pfx: Vec<u8>) -> Self
pub fn new(lease: LeaseClient, pfx: Vec<u8>) -> Self
Wrap a Lease interface to filter for only keys with a prefix and remove that prefix when fetching attached keys through TimeToLive.
pub async fn time_to_live( &mut self, id: i64, options: Option<LeaseTimeToLiveOptions>, ) -> Result<LeaseTimeToLiveResponse, Error>