Struct etcd_client::LockOptions [−][src]
#[repr(transparent)]pub struct LockOptions(_);
Options for Lock operation.
Implementations
impl LockOptions[src]
impl LockOptions[src]pub const fn new() -> Self[src]
Creates a LockOptions.
pub const fn with_lease(self, lease: i64) -> Self[src]
lease is the ID of the lease that will be attached to ownership of the
lock. If the lease expires or is revoked and currently holds the lock,
the lock is automatically released. Calls to Lock with the same lease will
be treated as a single acquisition; locking twice with the same lease is a
no-op.