Struct etcd_client::LockResponse [−][src]
#[repr(transparent)]pub struct LockResponse(_);
Response for Lock operation.
Implementations
impl LockResponse[src]
impl LockResponse[src]pub fn header(&self) -> Option<&ResponseHeader>[src]
Get response header.
pub fn take_header(&mut self) -> Option<ResponseHeader>[src]
Takes the header out of the response, leaving a None in its place.
pub fn key(&self) -> &[u8][src]
A key that will exist on etcd for the duration that the Lock caller owns the lock. Users should not modify this key or the lock may exhibit undefined behavior.