Struct etcd_client::Member [−][src]
#[repr(transparent)]pub struct Member(_);
Cluster member.
Implementations
impl Member[src]
impl Member[src]pub const fn id(&self) -> u64[src]
Member id.
pub fn name(&self) -> &str[src]
The human-readable name of the member. If the member is not started, the name will be an empty string.
pub fn peer_urls(&self) -> &[String][src]
The list of URLs the member exposes to the cluster for communication.
pub fn client_urls(&self) -> &[String][src]
The list of URLs the member exposes to clients for communication. If the member is not started, client URLs will be empty.
pub const fn is_learner(&self) -> bool[src]
Indicates if the member is raft learner.