Struct etcd_client::Permission [−][src]
pub struct Permission { /* fields omitted */ }Role access permission.
Implementations
impl Permission[src]
impl Permission[src]pub fn new(perm_type: PermissionType, key: impl Into<Vec<u8>>) -> Self[src]
Creates a permission with operation type and key
pub fn read(key: impl Into<Vec<u8>>) -> Self[src]
Creates a read permission with key
pub fn write(key: impl Into<Vec<u8>>) -> Self[src]
Creates a write permission with key
pub fn read_write(key: impl Into<Vec<u8>>) -> Self[src]
Creates a read write permission with key
pub fn with_range_end(self, range_end: impl Into<Vec<u8>>) -> Self[src]
Sets range end for the permission
pub fn with_from_key(self) -> Self[src]
Sets the permission with all keys >= key.
pub fn with_prefix(self) -> Self[src]
Sets the permission with all keys prefixed with key.
pub fn with_all_keys(self) -> Self[src]
Sets the permission with all keys.
pub fn key(&self) -> &[u8][src]
The key in bytes. An empty key is not allowed.
pub fn range_end(&self) -> &[u8][src]
The range end in bytes. maybe empty
pub fn key_str(&self) -> Result<&str, Error>[src]
The key in string. An empty key is not allowed.
pub unsafe fn key_str_unchecked(&self) -> &str[src]
The key in string. An empty key is not allowed.
Safety
This function is unsafe because it does not check that the bytes of the key are valid UTF-8.
If this constraint is violated, undefined behavior results,
as the rest of Rust assumes that &strs are valid UTF-8.
pub fn range_end_str(&self) -> Result<&str, Error>[src]
The range end in string.
pub unsafe fn range_end_str_unchecked(&self) -> &str[src]
The range end in string.
Safety
This function is unsafe because it does not check that the bytes of the key are valid UTF-8.
If this constraint is violated, undefined behavior results,
as the rest of Rust assumes that &strs are valid UTF-8.
pub const fn get_type(&self) -> i32[src]
Gets the operation type of permission.
pub const fn is_from_key(&self) -> bool[src]
Indicates whether permission is with keys >= key.
pub const fn is_prefix(&self) -> bool[src]
Indicates whether permission is with all keys prefixed with key.