Struct etcd_client::SnapshotResponse [−][src]
#[repr(transparent)]pub struct SnapshotResponse(_);
Response for snapshot operation.
Implementations
impl SnapshotResponse[src]
impl SnapshotResponse[src]pub fn header(&self) -> Option<&ResponseHeader>[src]
Get response header.
pub fn take_header(&mut self) -> Option<ResponseHeader>[src]
Takes the header out of the response, leaving a None in its place.
pub fn remaining_bytes(&self) -> u64[src]
Get remaining bytes.
pub fn blob(&self) -> &[u8][src]
The next chunk of the snapshot in the snapshot stream.