Struct etcd_client::TlsOptions [−][src]
pub struct TlsOptions { /* fields omitted */ }This is supported on crate feature
tls only.Configures TLS settings for endpoints.
Implementations
impl ClientTlsConfig[src]
impl ClientTlsConfig[src]pub fn new() -> ClientTlsConfig[src]
Creates a new ClientTlsConfig using Rustls.
pub fn domain_name(self, domain_name: impl Into<String>) -> ClientTlsConfig[src]
Sets the domain name against which to verify the server’s TLS certificate.
pub fn ca_certificate(self, ca_certificate: Certificate) -> ClientTlsConfig[src]
Sets the CA Certificate against which to verify the server’s TLS certificate.
This has no effect if rustls_client_config is used to configure Rustls.
pub fn identity(self, identity: Identity) -> ClientTlsConfig[src]
Sets the client identity to present to the server.
This has no effect if rustls_client_config is used to configure Rustls.
pub fn rustls_client_config(self, config: ClientConfig) -> ClientTlsConfig[src]
Use options specified by the given ClientConfig to configure TLS.
This overrides all other TLS options set via other means.