Struct etcd_client::TxnResponse [−][src]
#[repr(transparent)]pub struct TxnResponse(_);
Response for Txn operation.
Implementations
impl TxnResponse[src]
impl TxnResponse[src]pub fn header(&self) -> Option<&ResponseHeader>[src]
Transaction response header.
pub fn take_header(&mut self) -> Option<ResponseHeader>[src]
Takes the header out of the response, leaving a None in its place.
pub const fn succeeded(&self) -> bool[src]
Returns true if the compare evaluated to true or false otherwise.
pub fn op_responses(&self) -> Vec<TxnOpResponse>[src]
Returns responses of transaction operations.