WatchRequestSender

Struct WatchRequestSender 

pub struct WatchRequestSender(/* private fields */);
The sender for sending watch requests in the existing watch stream.

The watch request can be sending using the WatchStream or the WatchRequestSender.

The WatchRequestSender can be obtained by splitting the WatchStream using the WatchStream::split method.

Implementations

Source

impl WatchRequestSender

pub async fn watch( &mut self, key: impl Into<Vec<u8>>, options: Option<WatchOptions>, ) -> Result<(), Error>

Send watch request in the existing watch stream.

See also WatchStream::watch for sending watch request using WatchStream.

pub async fn cancel(&mut self, watch_id: i64) -> Result<(), Error>

Cancels watch by specified watch_id.

See also WatchStream::cancel for canceling watch using WatchStream.

pub async fn request_progress(&mut self) -> Result<(), Error>

Requests a watch stream progress status be sent in the watch response stream as soon as possible.

See also WatchStream::request_progress for requesting watch stream progress status using WatchStream.