Struct etcd_client::Watcher [−][src]
pub struct Watcher { /* fields omitted */ }The watching handle.
Implementations
impl Watcher[src]
impl Watcher[src]pub const fn watch_id(&self) -> i64[src]
The ID of the watcher.
pub async fn cancel(&mut self) -> Result<(), Error>[src]
Cancels this watcher.
pub async fn request_progress(&mut self) -> Result<(), Error>[src]
Requests a watch stream progress status be sent in the watch response stream as soon as possible.