Struct etcd_client::WatchClient [−][src]
#[repr(transparent)]pub struct WatchClient { /* fields omitted */ }
Client for watch operations.
Implementations
impl WatchClient[src]
impl WatchClient[src]pub async fn watch(
&mut self,
key: impl Into<Vec<u8>>,
options: Option<WatchOptions>
) -> Result<(Watcher, WatchStream), Error>[src]
&mut self,
key: impl Into<Vec<u8>>,
options: Option<WatchOptions>
) -> Result<(Watcher, WatchStream), Error>
Watches for events happening or that have happened. Both input and output are streams; the input stream is for creating and canceling watchers and the output stream sends events. One watch RPC can watch on multiple key ranges, streaming events for several watches at once. The entire event history can be watched starting from the last compaction revision.